"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class S3VMUploadRequestTypedDict(TypedDict):
    s3_url: str
    r"""The S3 URL of the file to upload"""
    file_name: str
    r"""Original name of the file"""
    file_type: NotRequired[str]
    r"""MIME type of the file"""
    target_path: NotRequired[str]
    r"""Target path on the VM (defaults to Users/Administrator/Desktop/{file_name})"""


class S3VMUploadRequest(BaseModel):
    s3_url: str
    r"""The S3 URL of the file to upload"""

    file_name: str
    r"""Original name of the file"""

    file_type: Optional[str] = None
    r"""MIME type of the file"""

    target_path: Optional[str] = None
    r"""Target path on the VM (defaults to Users/Administrator/Desktop/{file_name})"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk import utils
from skylight_sdk.types import BaseModel


class WindowsModelsErrorResponseData(BaseModel):
    detail: str
    r"""Error message describing what went wrong"""


class WindowsModelsErrorResponse(Exception):
    r"""Standard error response containing details about the error"""

    data: WindowsModelsErrorResponseData

    def __init__(self, data: WindowsModelsErrorResponseData):
        self.data = data

    def __str__(self) -> str:
        return utils.marshal_json(self.data, WindowsModelsErrorResponseData)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk import utils
from skylight_sdk.types import BaseModel
from typing import Optional


class ForbiddenErrorResponseData(BaseModel):
    detail: Optional[str] = "Access forbidden"
    r"""Error message for forbidden access"""


class ForbiddenErrorResponse(Exception):
    r"""Returned when the request cannot be processed due to authentication or authorization issues"""

    data: ForbiddenErrorResponseData

    def __init__(self, data: ForbiddenErrorResponseData):
        self.data = data

    def __str__(self) -> str:
        return utils.marshal_json(self.data, ForbiddenErrorResponseData)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .clickrequest import ClickRequest, ClickRequestTypedDict
from skylight_sdk.types import BaseModel
from skylight_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class ClickRequest1TypedDict(TypedDict):
    instance_id: str
    click_request: ClickRequestTypedDict


class ClickRequest1(BaseModel):
    instance_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    click_request: Annotated[
        ClickRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .instancestatusresponse import (
    InstanceStatusResponse,
    InstanceStatusResponseTypedDict,
)
from skylight_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class InstancesListResponseTypedDict(TypedDict):
    instances: List[InstanceStatusResponseTypedDict]
    r"""List of instances associated with the API key"""


class InstancesListResponse(BaseModel):
    instances: List[InstanceStatusResponse]
    r"""List of instances associated with the API key"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .keyrequest import KeyRequest, KeyRequestTypedDict
from skylight_sdk.types import BaseModel
from skylight_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class KeypressRequestTypedDict(TypedDict):
    instance_id: str
    key_request: KeyRequestTypedDict


class KeypressRequest(BaseModel):
    instance_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    key_request: Annotated[
        KeyRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from pydantic import model_serializer
from skylight_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing import List
from typing_extensions import NotRequired, TypedDict


class AgentStatusResponseFilesTypedDict(TypedDict):
    pass


class AgentStatusResponseFiles(BaseModel):
    pass


class HumanInputRequestTypedDict(TypedDict):
    pass


class HumanInputRequest(BaseModel):
    pass


class AgentStatusResponseTypedDict(TypedDict):
    agent_status: str
    r"""Current status of the agent"""
    is_running: bool
    r"""Whether the agent is currently running"""
    total_steps: int
    r"""Total number of steps executed"""
    files: List[AgentStatusResponseFilesTypedDict]
    r"""List of files downloaded by the agent"""
    messages: List[str]
    r"""List of steps executed by the agent"""
    created_at: str
    r"""Timestamp when the agent was created"""
    query: str
    r"""Original query given to the agent"""
    agent_id: str
    r"""Unique identifier for the agent"""
    final_summary: NotRequired[Nullable[str]]
    r"""Final summary of agent execution"""
    human_input_request: NotRequired[Nullable[HumanInputRequestTypedDict]]
    r"""Information about the human input being requested, if agent is waiting"""


class AgentStatusResponse(BaseModel):
    agent_status: str
    r"""Current status of the agent"""

    is_running: bool
    r"""Whether the agent is currently running"""

    total_steps: int
    r"""Total number of steps executed"""

    files: List[AgentStatusResponseFiles]
    r"""List of files downloaded by the agent"""

    messages: List[str]
    r"""List of steps executed by the agent"""

    created_at: str
    r"""Timestamp when the agent was created"""

    query: str
    r"""Original query given to the agent"""

    agent_id: str
    r"""Unique identifier for the agent"""

    final_summary: OptionalNullable[str] = UNSET
    r"""Final summary of agent execution"""

    human_input_request: OptionalNullable[HumanInputRequest] = UNSET
    r"""Information about the human input being requested, if agent is waiting"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["final_summary", "human_input_request"]
        nullable_fields = ["final_summary", "human_input_request"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class KeyRequestTypedDict(TypedDict):
    keys: List[str]


class KeyRequest(BaseModel):
    keys: List[str]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk.types import BaseModel
from typing_extensions import TypedDict


class StandardResponseTypedDict(TypedDict):
    status: str
    r"""Status of the operation"""
    message: str
    r"""Human-readable status message"""


class StandardResponse(BaseModel):
    status: str
    r"""Status of the operation"""

    message: str
    r"""Human-readable status message"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .activeoperationresponse import (
    ActiveOperationResponse,
    ActiveOperationResponseTypedDict,
)
from .agentstatusresponse import (
    AgentStatusResponse,
    AgentStatusResponseFiles,
    AgentStatusResponseFilesTypedDict,
    AgentStatusResponseTypedDict,
    HumanInputRequest,
    HumanInputRequestTypedDict,
)
from .answerop import (
    AnswerRequest,
    AnswerRequestTypedDict,
    AnswerResponse,
    AnswerResponseTypedDict,
)
from .apierror import APIError
from .clauderequest import (
    ClaudeRequest,
    ClaudeRequestTypedDict,
    Messages,
    MessagesTypedDict,
)
from .clickop import ClickRequest1, ClickRequest1TypedDict
from .clickrequest import Button, ClickRequest, ClickRequestTypedDict
from .downloadop import DownloadRequest, DownloadRequestTypedDict
from .dragop import DragRequest1, DragRequest1TypedDict
from .dragrequest import DragRequest, DragRequestButton, DragRequestTypedDict
from .filedownloadresponse import FileDownloadResponse, FileDownloadResponseTypedDict
from .fileuploadresponse import FileUploadResponse, FileUploadResponseTypedDict
from .forbiddenerrorresponse import ForbiddenErrorResponse, ForbiddenErrorResponseData
from .httpvalidationerror import HTTPValidationError, HTTPValidationErrorData
from .inactiveoperationresponse import (
    InactiveOperationResponse,
    InactiveOperationResponseTypedDict,
)
from .installop import InstallRequest, InstallRequestTypedDict
from .instancerequest import InstanceRequest, InstanceRequestTypedDict
from .instanceslistresponse import InstancesListResponse, InstancesListResponseTypedDict
from .instancestartresponse import InstanceStartResponse, InstanceStartResponseTypedDict
from .instancestatusresponse import (
    FilesModel,
    FilesModelTypedDict,
    InstanceStatusResponse,
    InstanceStatusResponseTypedDict,
)
from .interact_models_errorresponse import (
    InteractModelsErrorResponse,
    InteractModelsErrorResponseData,
)
from .keypressop import KeypressRequest, KeypressRequestTypedDict
from .keyrequest import KeyRequest, KeyRequestTypedDict
from .mousemoverequest import MouseMoveRequest, MouseMoveRequestTypedDict
from .moveop import MoveRequest, MoveRequestTypedDict
from .packageinstallrequest import PackageInstallRequest, PackageInstallRequestTypedDict
from .packageinstallresponse import (
    PackageInstallResponse,
    PackageInstallResponseTypedDict,
)
from .pauseop import PauseRequest, PauseRequestTypedDict
from .resumeop import ResumeRequest, ResumeRequestTypedDict
from .runop import RunRequest, RunRequestTypedDict
from .s3vmuploadrequest import S3VMUploadRequest, S3VMUploadRequestTypedDict
from .screenshotop import ScreenshotRequest, ScreenshotRequestTypedDict
from .screenshotresponse import ScreenshotResponse, ScreenshotResponseTypedDict
from .scrollop import ScrollRequest1, ScrollRequest1TypedDict
from .scrollrequest import ScrollRequest, ScrollRequestTypedDict
from .security import Security, SecurityTypedDict
from .standardresponse import StandardResponse, StandardResponseTypedDict
from .stateop import StateRequest, StateRequestTypedDict
from .statusop import StatusRequest, StatusRequestTypedDict
from .stopop import StopRequest, StopRequestTypedDict
from .terminateop import TerminateRequest, TerminateRequestTypedDict
from .typeop import TypeRequest1, TypeRequest1TypedDict
from .typerequest import TypeRequest, TypeRequestTypedDict
from .uploadop import UploadRequest, UploadRequestTypedDict
from .validationerror import (
    Loc,
    LocTypedDict,
    ValidationError,
    ValidationErrorTypedDict,
)
from .windows_models_errorresponse import (
    WindowsModelsErrorResponse,
    WindowsModelsErrorResponseData,
)


__all__ = [
    "APIError",
    "ActiveOperationResponse",
    "ActiveOperationResponseTypedDict",
    "AgentStatusResponse",
    "AgentStatusResponseFiles",
    "AgentStatusResponseFilesTypedDict",
    "AgentStatusResponseTypedDict",
    "AnswerRequest",
    "AnswerRequestTypedDict",
    "AnswerResponse",
    "AnswerResponseTypedDict",
    "Button",
    "ClaudeRequest",
    "ClaudeRequestTypedDict",
    "ClickRequest",
    "ClickRequest1",
    "ClickRequest1TypedDict",
    "ClickRequestTypedDict",
    "DownloadRequest",
    "DownloadRequestTypedDict",
    "DragRequest",
    "DragRequest1",
    "DragRequest1TypedDict",
    "DragRequestButton",
    "DragRequestTypedDict",
    "FileDownloadResponse",
    "FileDownloadResponseTypedDict",
    "FileUploadResponse",
    "FileUploadResponseTypedDict",
    "FilesModel",
    "FilesModelTypedDict",
    "ForbiddenErrorResponse",
    "ForbiddenErrorResponseData",
    "HTTPValidationError",
    "HTTPValidationErrorData",
    "HumanInputRequest",
    "HumanInputRequestTypedDict",
    "InactiveOperationResponse",
    "InactiveOperationResponseTypedDict",
    "InstallRequest",
    "InstallRequestTypedDict",
    "InstanceRequest",
    "InstanceRequestTypedDict",
    "InstanceStartResponse",
    "InstanceStartResponseTypedDict",
    "InstanceStatusResponse",
    "InstanceStatusResponseTypedDict",
    "InstancesListResponse",
    "InstancesListResponseTypedDict",
    "InteractModelsErrorResponse",
    "InteractModelsErrorResponseData",
    "KeyRequest",
    "KeyRequestTypedDict",
    "KeypressRequest",
    "KeypressRequestTypedDict",
    "Loc",
    "LocTypedDict",
    "Messages",
    "MessagesTypedDict",
    "MouseMoveRequest",
    "MouseMoveRequestTypedDict",
    "MoveRequest",
    "MoveRequestTypedDict",
    "PackageInstallRequest",
    "PackageInstallRequestTypedDict",
    "PackageInstallResponse",
    "PackageInstallResponseTypedDict",
    "PauseRequest",
    "PauseRequestTypedDict",
    "ResumeRequest",
    "ResumeRequestTypedDict",
    "RunRequest",
    "RunRequestTypedDict",
    "S3VMUploadRequest",
    "S3VMUploadRequestTypedDict",
    "ScreenshotRequest",
    "ScreenshotRequestTypedDict",
    "ScreenshotResponse",
    "ScreenshotResponseTypedDict",
    "ScrollRequest",
    "ScrollRequest1",
    "ScrollRequest1TypedDict",
    "ScrollRequestTypedDict",
    "Security",
    "SecurityTypedDict",
    "StandardResponse",
    "StandardResponseTypedDict",
    "StateRequest",
    "StateRequestTypedDict",
    "StatusRequest",
    "StatusRequestTypedDict",
    "StopRequest",
    "StopRequestTypedDict",
    "TerminateRequest",
    "TerminateRequestTypedDict",
    "TypeRequest",
    "TypeRequest1",
    "TypeRequest1TypedDict",
    "TypeRequestTypedDict",
    "UploadRequest",
    "UploadRequestTypedDict",
    "ValidationError",
    "ValidationErrorTypedDict",
    "WindowsModelsErrorResponse",
    "WindowsModelsErrorResponseData",
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk.types import BaseModel
from typing import List, Union
from typing_extensions import TypeAliasType, TypedDict


LocTypedDict = TypeAliasType("LocTypedDict", Union[str, int])


Loc = TypeAliasType("Loc", Union[str, int])


class ValidationErrorTypedDict(TypedDict):
    loc: List[LocTypedDict]
    msg: str
    type: str


class ValidationError(BaseModel):
    loc: List[Loc]

    msg: str

    type: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from skylight_sdk import models, utils
from skylight_sdk._hooks import HookContext
from skylight_sdk.types import OptionalNullable, UNSET
from skylight_sdk.utils import get_security_from_env
from typing import Any, Dict, List, Mapping, Optional


class Interact(BaseSDK):
    def click(
        self,
        *,
        instance_id: str,
        x: OptionalNullable[int] = UNSET,
        y: OptionalNullable[int] = UNSET,
        button: Optional[models.Button] = models.Button.LEFT,
        clicks: Optional[int] = 1,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.StandardResponse:
        r"""Click

        Perform a click operation at the specified coordinates or current position

        - If x and y are provided, click at those coordinates
        - If x and y are omitted, click at the current cursor position
        - Use button=\"left\", clicks=1 for a single left click
        - Use button=\"right\", clicks=1 for a right click
        - Use button=\"middle\", clicks=1 for a middle click
        - Use button=\"left\", clicks=2 for a double click

        Requires API key authentication.

        :param instance_id:
        :param x:
        :param y:
        :param button:
        :param clicks:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ClickRequest1(
            instance_id=instance_id,
            click_request=models.ClickRequest(
                x=x,
                y=y,
                button=button,
                clicks=clicks,
            ),
        )

        req = self._build_request(
            method="POST",
            path="/interact/click/{instance_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.click_request, False, False, "json", models.ClickRequest
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="click",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["403", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.StandardResponse)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ForbiddenErrorResponseData
            )
            raise models.ForbiddenErrorResponse(data=response_data)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.HTTPValidationErrorData
            )
            raise models.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.InteractModelsErrorResponseData
            )
            raise models.InteractModelsErrorResponse(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def click_async(
        self,
        *,
        instance_id: str,
        x: OptionalNullable[int] = UNSET,
        y: OptionalNullable[int] = UNSET,
        button: Optional[models.Button] = models.Button.LEFT,
        clicks: Optional[int] = 1,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.StandardResponse:
        r"""Click

        Perform a click operation at the specified coordinates or current position

        - If x and y are provided, click at those coordinates
        - If x and y are omitted, click at the current cursor position
        - Use button=\"left\", clicks=1 for a single left click
        - Use button=\"right\", clicks=1 for a right click
        - Use button=\"middle\", clicks=1 for a middle click
        - Use button=\"left\", clicks=2 for a double click

        Requires API key authentication.

        :param instance_id:
        :param x:
        :param y:
        :param button:
        :param clicks:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ClickRequest1(
            instance_id=instance_id,
            click_request=models.ClickRequest(
                x=x,
                y=y,
                button=button,
                clicks=clicks,
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/interact/click/{instance_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.click_request, False, False, "json", models.ClickRequest
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="click",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["403", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.StandardResponse)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ForbiddenErrorResponseData
            )
            raise models.ForbiddenErrorResponse(data=response_data)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.HTTPValidationErrorData
            )
            raise models.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.InteractModelsErrorResponseData
            )
            raise models.InteractModelsErrorResponse(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def drag(
        self,
        *,
        instance_id: str,
        path: List[Dict[str, int]],
        button: Optional[models.DragRequestButton] = models.DragRequestButton.LEFT,
        step: OptionalNullable[int] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.StandardResponse:
        r"""Drag

        Perform a drag operation along a path of coordinates

        - path: List of points to drag through, each with 'x' and 'y' coordinates
        - button: Mouse button to use for dragging (default: \"left\")

        Requires API key authentication.

        :param instance_id:
        :param path:
        :param button:
        :param step: Optional step size for drag movements. If not provided, movement will be continuous.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.DragRequest1(
            instance_id=instance_id,
            drag_request=models.DragRequest(
                path=path,
                button=button,
                step=step,
            ),
        )

        req = self._build_request(
            method="POST",
            path="/interact/drag/{instance_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.drag_request, False, False, "json", models.DragRequest
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="drag",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["403", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.StandardResponse)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ForbiddenErrorResponseData
            )
            raise models.ForbiddenErrorResponse(data=response_data)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.HTTPValidationErrorData
            )
            raise models.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.InteractModelsErrorResponseData
            )
            raise models.InteractModelsErrorResponse(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def drag_async(
        self,
        *,
        instance_id: str,
        path: List[Dict[str, int]],
        button: Optional[models.DragRequestButton] = models.DragRequestButton.LEFT,
        step: OptionalNullable[int] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.StandardResponse:
        r"""Drag

        Perform a drag operation along a path of coordinates

        - path: List of points to drag through, each with 'x' and 'y' coordinates
        - button: Mouse button to use for dragging (default: \"left\")

        Requires API key authentication.

        :param instance_id:
        :param path:
        :param button:
        :param step: Optional step size for drag movements. If not provided, movement will be continuous.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.DragRequest1(
            instance_id=instance_id,
            drag_request=models.DragRequest(
                path=path,
                button=button,
                step=step,
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/interact/drag/{instance_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.drag_request, False, False, "json", models.DragRequest
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="drag",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["403", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.StandardResponse)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ForbiddenErrorResponseData
            )
            raise models.ForbiddenErrorResponse(data=response_data)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.HTTPValidationErrorData
            )
            raise models.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.InteractModelsErrorResponseData
            )
            raise models.InteractModelsErrorResponse(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def screenshot(
        self,
        *,
        instance_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ScreenshotResponse:
        r"""Take Screenshot

        Take a screenshot of the instance

        Requires API key authentication.

        :param instance_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ScreenshotRequest(
            instance_id=instance_id,
        )

        req = self._build_request(
            method="POST",
            path="/interact/screenshot/{instance_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="screenshot",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["403", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.ScreenshotResponse)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ForbiddenErrorResponseData
            )
            raise models.ForbiddenErrorResponse(data=response_data)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.HTTPValidationErrorData
            )
            raise models.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.InteractModelsErrorResponseData
            )
            raise models.InteractModelsErrorResponse(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def screenshot_async(
        self,
        *,
        instance_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ScreenshotResponse:
        r"""Take Screenshot

        Take a screenshot of the instance

        Requires API key authentication.

        :param instance_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ScreenshotRequest(
            instance_id=instance_id,
        )

        req = self._build_request_async(
            method="POST",
            path="/interact/screenshot/{instance_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="screenshot",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["403", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.ScreenshotResponse)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ForbiddenErrorResponseData
            )
            raise models.ForbiddenErrorResponse(data=response_data)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.HTTPValidationErrorData
            )
            raise models.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.InteractModelsErrorResponseData
            )
            raise models.InteractModelsErrorResponse(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def move(
        self,
        *,
        instance_id: str,
        x: int,
        y: int,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.StandardResponse:
        r"""Move Mouse

        Move the mouse to the specified coordinates

        Requires API key authentication.

        :param instance_id:
        :param x:
        :param y:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.MoveRequest(
            instance_id=instance_id,
            mouse_move_request=models.MouseMoveRequest(
                x=x,
                y=y,
            ),
        )

        req = self._build_request(
            method="POST",
            path="/interact/move/{instance_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.mouse_move_request,
                False,
                False,
                "json",
                models.MouseMoveRequest,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="move",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["403", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.StandardResponse)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ForbiddenErrorResponseData
            )
            raise models.ForbiddenErrorResponse(data=response_data)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.HTTPValidationErrorData
            )
            raise models.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.InteractModelsErrorResponseData
            )
            raise models.InteractModelsErrorResponse(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def move_async(
        self,
        *,
        instance_id: str,
        x: int,
        y: int,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.StandardResponse:
        r"""Move Mouse

        Move the mouse to the specified coordinates

        Requires API key authentication.

        :param instance_id:
        :param x:
        :param y:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.MoveRequest(
            instance_id=instance_id,
            mouse_move_request=models.MouseMoveRequest(
                x=x,
                y=y,
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/interact/move/{instance_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.mouse_move_request,
                False,
                False,
                "json",
                models.MouseMoveRequest,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="move",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["403", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.StandardResponse)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ForbiddenErrorResponseData
            )
            raise models.ForbiddenErrorResponse(data=response_data)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.HTTPValidationErrorData
            )
            raise models.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.InteractModelsErrorResponseData
            )
            raise models.InteractModelsErrorResponse(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def keypress(
        self,
        *,
        instance_id: str,
        keys: List[str],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.StandardResponse:
        r"""Keypress

        Press the specified keys simultaneously (e.g. ['ctrl', 'alt', 'delete'])

        Requires API key authentication.

        :param instance_id:
        :param keys:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.KeypressRequest(
            instance_id=instance_id,
            key_request=models.KeyRequest(
                keys=keys,
            ),
        )

        req = self._build_request(
            method="POST",
            path="/interact/keypress/{instance_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.key_request, False, False, "json", models.KeyRequest
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="keypress",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "403", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.StandardResponse)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.InteractModelsErrorResponseData
            )
            raise models.InteractModelsErrorResponse(data=response_data)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ForbiddenErrorResponseData
            )
            raise models.ForbiddenErrorResponse(data=response_data)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.HTTPValidationErrorData
            )
            raise models.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.InteractModelsErrorResponseData
            )
            raise models.InteractModelsErrorResponse(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def keypress_async(
        self,
        *,
        instance_id: str,
        keys: List[str],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.StandardResponse:
        r"""Keypress

        Press the specified keys simultaneously (e.g. ['ctrl', 'alt', 'delete'])

        Requires API key authentication.

        :param instance_id:
        :param keys:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.KeypressRequest(
            instance_id=instance_id,
            key_request=models.KeyRequest(
                keys=keys,
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/interact/keypress/{instance_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.key_request, False, False, "json", models.KeyRequest
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="keypress",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "403", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.StandardResponse)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.InteractModelsErrorResponseData
            )
            raise models.InteractModelsErrorResponse(data=response_data)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ForbiddenErrorResponseData
            )
            raise models.ForbiddenErrorResponse(data=response_data)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.HTTPValidationErrorData
            )
            raise models.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.InteractModelsErrorResponseData
            )
            raise models.InteractModelsErrorResponse(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def type(
        self,
        *,
        instance_id: str,
        text: str,
        interval: OptionalNullable[float] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.StandardResponse:
        r"""Type Text

        Type the specified text with optional delay between keystrokes

        Requires API key authentication.

        :param instance_id:
        :param text:
        :param interval:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.TypeRequest1(
            instance_id=instance_id,
            type_request=models.TypeRequest(
                text=text,
                interval=interval,
            ),
        )

        req = self._build_request(
            method="POST",
            path="/interact/type/{instance_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.type_request, False, False, "json", models.TypeRequest
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="type",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["403", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.StandardResponse)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ForbiddenErrorResponseData
            )
            raise models.ForbiddenErrorResponse(data=response_data)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.HTTPValidationErrorData
            )
            raise models.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.InteractModelsErrorResponseData
            )
            raise models.InteractModelsErrorResponse(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def type_async(
        self,
        *,
        instance_id: str,
        text: str,
        interval: OptionalNullable[float] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.StandardResponse:
        r"""Type Text

        Type the specified text with optional delay between keystrokes

        Requires API key authentication.

        :param instance_id:
        :param text:
        :param interval:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.TypeRequest1(
            instance_id=instance_id,
            type_request=models.TypeRequest(
                text=text,
                interval=interval,
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/interact/type/{instance_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.type_request, False, False, "json", models.TypeRequest
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="type",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["403", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.StandardResponse)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ForbiddenErrorResponseData
            )
            raise models.ForbiddenErrorResponse(data=response_data)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.HTTPValidationErrorData
            )
            raise models.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.InteractModelsErrorResponseData
            )
            raise models.InteractModelsErrorResponse(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def scroll(
        self,
        *,
        instance_id: str,
        x: int,
        y: int,
        scroll_x: Optional[int] = 0,
        scroll_y: Optional[int] = 0,
        step: OptionalNullable[int] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.StandardResponse:
        r"""Scroll

        Scroll at the specified coordinates

        Requires API key authentication.

        :param instance_id:
        :param x:
        :param y:
        :param scroll_x: Horizontal scroll amount
        :param scroll_y: Vertical scroll amount
        :param step: Optional step size for scroll movements. If not provided, movement will be continuous.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ScrollRequest1(
            instance_id=instance_id,
            scroll_request=models.ScrollRequest(
                x=x,
                y=y,
                scroll_x=scroll_x,
                scroll_y=scroll_y,
                step=step,
            ),
        )

        req = self._build_request(
            method="POST",
            path="/interact/scroll/{instance_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.scroll_request, False, False, "json", models.ScrollRequest
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="scroll",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["403", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.StandardResponse)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ForbiddenErrorResponseData
            )
            raise models.ForbiddenErrorResponse(data=response_data)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.HTTPValidationErrorData
            )
            raise models.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.InteractModelsErrorResponseData
            )
            raise models.InteractModelsErrorResponse(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def scroll_async(
        self,
        *,
        instance_id: str,
        x: int,
        y: int,
        scroll_x: Optional[int] = 0,
        scroll_y: Optional[int] = 0,
        step: OptionalNullable[int] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.StandardResponse:
        r"""Scroll

        Scroll at the specified coordinates

        Requires API key authentication.

        :param instance_id:
        :param x:
        :param y:
        :param scroll_x: Horizontal scroll amount
        :param scroll_y: Vertical scroll amount
        :param step: Optional step size for scroll movements. If not provided, movement will be continuous.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ScrollRequest1(
            instance_id=instance_id,
            scroll_request=models.ScrollRequest(
                x=x,
                y=y,
                scroll_x=scroll_x,
                scroll_y=scroll_y,
                step=step,
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/interact/scroll/{instance_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.scroll_request, False, False, "json", models.ScrollRequest
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="scroll",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["403", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.StandardResponse)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ForbiddenErrorResponseData
            )
            raise models.ForbiddenErrorResponse(data=response_data)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.HTTPValidationErrorData
            )
            raise models.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.InteractModelsErrorResponseData
            )
            raise models.InteractModelsErrorResponse(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def install(
        self,
        *,
        instance_id: str,
        packages: List[str],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PackageInstallResponse:
        r"""Install Applications

        Install Chocolatey packages on a Windows instance. Find a list of packages here: https://community.chocolatey.org/packages.

        Requires API key authentication.

        :param instance_id:
        :param packages: List of Chocolatey package names to install
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.InstallRequest(
            instance_id=instance_id,
            package_install_request=models.PackageInstallRequest(
                packages=packages,
            ),
        )

        req = self._build_request(
            method="POST",
            path="/interact/install/{instance_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.package_install_request,
                False,
                False,
                "json",
                models.PackageInstallRequest,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="install",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["403", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.PackageInstallResponse)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ForbiddenErrorResponseData
            )
            raise models.ForbiddenErrorResponse(data=response_data)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.HTTPValidationErrorData
            )
            raise models.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.InteractModelsErrorResponseData
            )
            raise models.InteractModelsErrorResponse(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def install_async(
        self,
        *,
        instance_id: str,
        packages: List[str],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PackageInstallResponse:
        r"""Install Applications

        Install Chocolatey packages on a Windows instance. Find a list of packages here: https://community.chocolatey.org/packages.

        Requires API key authentication.

        :param instance_id:
        :param packages: List of Chocolatey package names to install
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.InstallRequest(
            instance_id=instance_id,
            package_install_request=models.PackageInstallRequest(
                packages=packages,
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/interact/install/{instance_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.package_install_request,
                False,
                False,
                "json",
                models.PackageInstallRequest,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="install",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["403", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.PackageInstallResponse)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ForbiddenErrorResponseData
            )
            raise models.ForbiddenErrorResponse(data=response_data)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.HTTPValidationErrorData
            )
            raise models.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.InteractModelsErrorResponseData
            )
            raise models.InteractModelsErrorResponse(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk.types import BaseModel
from skylight_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class PauseRequestTypedDict(TypedDict):
    instance_id: str


class PauseRequest(BaseModel):
    instance_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk.types import BaseModel
from typing_extensions import TypedDict


class FileDownloadResponseTypedDict(TypedDict):
    r"""Response containing a presigned URL to download a file"""

    status: str
    r"""Status of the operation"""
    message: str
    r"""Human-readable status message"""
    download_url: str
    r"""Presigned URL to download the file"""


class FileDownloadResponse(BaseModel):
    r"""Response containing a presigned URL to download a file"""

    status: str
    r"""Status of the operation"""

    message: str
    r"""Human-readable status message"""

    download_url: str
    r"""Presigned URL to download the file"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk.types import BaseModel
from skylight_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class AnswerResponseTypedDict(TypedDict):
    pass


class AnswerResponse(BaseModel):
    pass


class AnswerRequestTypedDict(TypedDict):
    agent_id: str
    request_body: AnswerResponseTypedDict


class AnswerRequest(BaseModel):
    agent_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    request_body: Annotated[
        AnswerResponse,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk.types import BaseModel
from typing_extensions import TypedDict


class FileUploadResponseTypedDict(TypedDict):
    r"""Response when a file is successfully uploaded to a VM"""

    status: str
    r"""Status of the operation"""
    message: str
    r"""Human-readable status message"""
    file_path: str
    r"""Path where the file was saved on the VM"""


class FileUploadResponse(BaseModel):
    r"""Response when a file is successfully uploaded to a VM"""

    status: str
    r"""Status of the operation"""

    message: str
    r"""Human-readable status message"""

    file_path: str
    r"""Path where the file was saved on the VM"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk.types import BaseModel
from typing_extensions import TypedDict


class MouseMoveRequestTypedDict(TypedDict):
    x: int
    y: int


class MouseMoveRequest(BaseModel):
    x: int

    y: int



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk.types import BaseModel
from typing_extensions import TypedDict


class InstanceStartResponseTypedDict(TypedDict):
    instance_id: str
    r"""Unique identifier of the created instance"""
    message: str
    r"""Human-readable status message"""
    livestream_url: str
    r"""URL to livestream the instance"""
    state: str
    r"""State of the instance (running, pending, hibernated, terminated)"""


class InstanceStartResponse(BaseModel):
    instance_id: str
    r"""Unique identifier of the created instance"""

    message: str
    r"""Human-readable status message"""

    livestream_url: str
    r"""URL to livestream the instance"""

    state: str
    r"""State of the instance (running, pending, hibernated, terminated)"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from skylight_sdk import models, utils
from skylight_sdk._hooks import HookContext
from skylight_sdk.types import OptionalNullable, UNSET
from skylight_sdk.utils import get_security_from_env
from typing import Any, Dict, Mapping, Optional


class Files(BaseSDK):
    def upload(
        self,
        *,
        instance_id: str,
        s3_url: str,
        file_name: str,
        file_type: Optional[str] = None,
        target_path: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.FileUploadResponse:
        r"""Upload To Vm

        Upload a file from S3 to the VM

        Takes an S3 URL (often from FileUploader component) and transfers it to the VM.
        Updates the files.uploads array in the vm_instances table to track the file.

        Requires API key authentication.

        :param instance_id:
        :param s3_url: The S3 URL of the file to upload
        :param file_name: Original name of the file
        :param file_type: MIME type of the file
        :param target_path: Target path on the VM (defaults to Users/Administrator/Desktop/{file_name})
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.UploadRequest(
            instance_id=instance_id,
            s3_vm_upload_request=models.S3VMUploadRequest(
                s3_url=s3_url,
                file_name=file_name,
                file_type=file_type,
                target_path=target_path,
            ),
        )

        req = self._build_request(
            method="POST",
            path="/windows/files/upload/{instance_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.s3_vm_upload_request,
                False,
                False,
                "json",
                models.S3VMUploadRequest,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="upload",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "403", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.FileUploadResponse)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.InteractModelsErrorResponseData
            )
            raise models.InteractModelsErrorResponse(data=response_data)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ForbiddenErrorResponseData
            )
            raise models.ForbiddenErrorResponse(data=response_data)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.HTTPValidationErrorData
            )
            raise models.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.InteractModelsErrorResponseData
            )
            raise models.InteractModelsErrorResponse(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def upload_async(
        self,
        *,
        instance_id: str,
        s3_url: str,
        file_name: str,
        file_type: Optional[str] = None,
        target_path: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.FileUploadResponse:
        r"""Upload To Vm

        Upload a file from S3 to the VM

        Takes an S3 URL (often from FileUploader component) and transfers it to the VM.
        Updates the files.uploads array in the vm_instances table to track the file.

        Requires API key authentication.

        :param instance_id:
        :param s3_url: The S3 URL of the file to upload
        :param file_name: Original name of the file
        :param file_type: MIME type of the file
        :param target_path: Target path on the VM (defaults to Users/Administrator/Desktop/{file_name})
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.UploadRequest(
            instance_id=instance_id,
            s3_vm_upload_request=models.S3VMUploadRequest(
                s3_url=s3_url,
                file_name=file_name,
                file_type=file_type,
                target_path=target_path,
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/windows/files/upload/{instance_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.s3_vm_upload_request,
                False,
                False,
                "json",
                models.S3VMUploadRequest,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="upload",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "403", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.FileUploadResponse)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.InteractModelsErrorResponseData
            )
            raise models.InteractModelsErrorResponse(data=response_data)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ForbiddenErrorResponseData
            )
            raise models.ForbiddenErrorResponse(data=response_data)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.HTTPValidationErrorData
            )
            raise models.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.InteractModelsErrorResponseData
            )
            raise models.InteractModelsErrorResponse(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def download(
        self,
        *,
        instance_id: str,
        request_body: Dict[str, str],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.FileDownloadResponse:
        r"""Get File

        Get a secure download link for a file on the instance

        Generates a presigned S3 URL for the client to download the file directly

        Requires API key authentication.

        :param instance_id:
        :param request_body:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.DownloadRequest(
            instance_id=instance_id,
            request_body=request_body,
        )

        req = self._build_request(
            method="POST",
            path="/windows/files/download/{instance_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.request_body, False, False, "json", Dict[str, str]
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="download",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["403", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.FileDownloadResponse)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ForbiddenErrorResponseData
            )
            raise models.ForbiddenErrorResponse(data=response_data)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.HTTPValidationErrorData
            )
            raise models.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.InteractModelsErrorResponseData
            )
            raise models.InteractModelsErrorResponse(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def download_async(
        self,
        *,
        instance_id: str,
        request_body: Dict[str, str],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.FileDownloadResponse:
        r"""Get File

        Get a secure download link for a file on the instance

        Generates a presigned S3 URL for the client to download the file directly

        Requires API key authentication.

        :param instance_id:
        :param request_body:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.DownloadRequest(
            instance_id=instance_id,
            request_body=request_body,
        )

        req = self._build_request_async(
            method="POST",
            path="/windows/files/download/{instance_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.request_body, False, False, "json", Dict[str, str]
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="download",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["403", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.FileDownloadResponse)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ForbiddenErrorResponseData
            )
            raise models.ForbiddenErrorResponse(data=response_data)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.HTTPValidationErrorData
            )
            raise models.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.InteractModelsErrorResponseData
            )
            raise models.InteractModelsErrorResponse(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk.types import BaseModel
from typing_extensions import TypedDict


class ScreenshotResponseTypedDict(TypedDict):
    image: str
    r"""Base64-encoded JPEG image of the instance screenshot"""


class ScreenshotResponse(BaseModel):
    image: str
    r"""Base64-encoded JPEG image of the instance screenshot"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk.types import BaseModel
from skylight_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import Dict
from typing_extensions import Annotated, TypedDict


class DownloadRequestTypedDict(TypedDict):
    instance_id: str
    request_body: Dict[str, str]


class DownloadRequest(BaseModel):
    instance_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    request_body: Annotated[
        Dict[str, str],
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PackageInstallRequestTypedDict(TypedDict):
    packages: List[str]
    r"""List of Chocolatey package names to install"""


class PackageInstallRequest(BaseModel):
    packages: List[str]
    r"""List of Chocolatey package names to install"""
